# pydear 🦌

ImGui wrapper generated by clang.cindex. 

- <https://github.com/ousttrue/pydear>
- <https://ousttrue.github.io/pydear/>
- <https://pypi.org/project/pydear/>

## build check

```
py -m pip wheel .
twine check pydear-1.12.1-cp310-cp310-linux_x86_64.whl
```
